%global pkgname float

Name:           gap-pkg-%{pkgname}
Version:        0.7.5
Release:        1%{?dist}
Summary:        GAP access to mpfr, mpfi, mpc, fplll and cxsc

License:        GPLv3+
URL:            http://gap-packages.github.io/float/
Source0:        https://github.com/gap-packages/%{pkgname}/releases/download/v%{version}/%{pkgname}-%{version}.tar.gz

BuildRequires:  cxsc-devel
BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gcc-c++
BuildRequires:  libfplll-devel
BuildRequires:  libmpc-devel
BuildRequires:  mpfi-devel
BuildRequires:  mpfr-devel
# Avoid a name clash; see https://github.com/gap-packages/float/issues/19
Patch0:         %{name}-name-clash.patch
# GCC needs 2 template instantiators that were removed in 0.7.5
Patch1:         %{name}-instantiator.patch

Requires:       gap-core

%description
This package implements floating-point numbers within GAP, with
arbitrary precision, based on the C libraries FPLLL, MPFR, MPFI, MPC
and CXSC.

%prep
%setup -q -n %{pkgname}-%{version}
%patch0
%patch1

%build
export CPPFLAGS="-I %{_includedir}/cxsc"
%configure --with-gaproot=%{_gap_dir}
sed -i 's,#define FPLLL_VERSION /\*\*/,#undef FPLLL_VERSION,' src/floatconfig.h
make %{?_smp_mflags}

# Build the documentation
mkdir ../pkg
ln -s ../%{pkgname}-%{version} ../pkg
gap -l "$PWD/..;%{_gap_dir}" makedoc.g
rm -fr ../pkg

%install
%make_install

# We do not want the libtool archive
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/bin/*/*.la

# Install the GAP files; we install test files for use by GAP's internal test
# suite runner.
cp -a *.g lib tst %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{lib,tst}/Makefile*

# Install the documentation
mkdir -p %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc
cp -p doc/*.{bib,css,html,js,lab,pdf,six,txt,xml} \
      %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc

%check
# Change from obsolete test method to modern method
sed -e '/ReadTest/s/);/, rec( compareFunction := "uptowhitespace" )&/' \
    -e 's/ReadTest/Test/' \
    -i tst/testall.g

gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" < tst/testall.g 2>&1 | tee log
grep -Fvq fail log
rm -f log

%files
%doc README THANKS
%license COPYING
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Mon Feb 20 2017 Jerry James <loganjerry@gmail.com> - 0.7.5-1
- New upstream version

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jul  1 2016 Jerry James <loganjerry@gmail.com> - 0.7.4-1
- Initial RPM
